@@ -3,6 +3,7 @@ __all__ = (
     'ResponseMixin', 'CreatePointMixin',
     'ID', 'Contract',
     'ListPointMixin',
+    'UploadFilePointMixin'
 )
 
 from typing import OrderedDict
@@ -65,6 +66,10 @@ class Point:
             else:
                 raise PointServerError(self._client.url, response.status_code)
 
+    def _post_file(self, file):
+        self._response = self._client.post_file(file=file)
+        self._handle_error(self._response)
+
 
 class ContractPoint(FilterMixin, Point):
     """Endpoints with validated data by contract"""
@@ -134,3 +139,8 @@ class ListPointMixin:
         if self._read_contract is None:
             raise PointError(f'Set attr read_contract')
         return self._get_sorted_data()
+
+
+class UploadFilePointMixin:
+    def upload_file(self, file):
+        self._post_file(file)
