@@ -5,7 +5,7 @@ secret_manager_client = secretmanager.SecretManagerServiceClient()
 access_secret_version = secretmanager_v1.types.service.AccessSecretVersionRequest()
 
 
-def get_secret(secret_key: str):
-    name = f'projects/829013617684/secrets/{secret_key}/versions/1'
+def get_secret(secret_key: str, version: int = 1):
+    name = f'projects/829013617684/secrets/{secret_key}/versions/{version}'
     access_secret_version.name = name
     return secret_manager_client.access_secret_version(request=access_secret_version).payload.data.decode("utf-8")
